@@ -5,6 +5,7 @@ use App::Netdisco::Worker::Plugin;
 use aliased 'App::Netdisco::Worker::Status';
 
 use App::Netdisco::Util::Device 'is_discoverable_now';
+use Time::HiRes 'gettimeofday';
 
 register_worker({ phase => 'check' }, sub {
   my ($job, $workerconf) = @_;
@@ -24,6 +25,13 @@ register_worker({ phase => 'check' }, sub {
   return Status->info("discover skipped: $device is not discoverable")
     unless is_discoverable_now($device);
 
+  # would be possible just to use LOCALTIMESTAMP on updated records, but by using this
+  # same value for them all, we can if we want add a job at the end to
+  # select and do something with the updated set (see set archive, below)
+  vars->{'timestamp'} = ($job->is_offline and $job->entered)
+    ? (schema('netdisco')->storage->dbh->quote($job->entered) .'::timestamp')
+    : 'to_timestamp('. (join '.', gettimeofday) .')::timestamp';
+
   return Status->done('Discover is able to run.');
 });
 
